"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const server_1 = require("./server");
function getDatabaseStructure(connectionUrl) {
    return __awaiter(this, void 0, void 0, function* () {
        const request = {
            method: 'POST',
            body: JSON.stringify({ connectionUrl })
        };
        const response = yield server_1.Server.makeRequest('/jupyterlab-sql/database', request);
        if (!response.ok) {
            return Private.createErrorResponse(response.status);
        }
        const data = yield response.json();
        return data;
    });
}
exports.getDatabaseStructure = getDatabaseStructure;
var DatabaseStructureResponse;
(function (DatabaseStructureResponse) {
    function createError(message) {
        return {
            responseType: 'error',
            responseData: {
                message
            }
        };
    }
    DatabaseStructureResponse.createError = createError;
    function createNotFoundError() {
        const errorMessage = 'Failed to reach server endpoints. ' +
            'Is the server extension installed correctly?';
        return createError(errorMessage);
    }
    DatabaseStructureResponse.createNotFoundError = createNotFoundError;
    function match(response, onSuccess, onError) {
        if (response.responseType === 'error') {
            return onError(response.responseData);
        }
        else if (response.responseType === 'success') {
            const { tables } = response.responseData;
            return onSuccess(tables);
        }
    }
    DatabaseStructureResponse.match = match;
})(DatabaseStructureResponse = exports.DatabaseStructureResponse || (exports.DatabaseStructureResponse = {}));
var Private;
(function (Private) {
    function createErrorResponse(responseStatus) {
        if (responseStatus === 404) {
            return DatabaseStructureResponse.createNotFoundError();
        }
        else {
            const errorMessage = 'Unexpected response status from server';
            return DatabaseStructureResponse.createError(errorMessage);
        }
    }
    Private.createErrorResponse = createErrorResponse;
})(Private || (Private = {}));
