"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const signaling_1 = require("@phosphor/signaling");
const apputils_1 = require("@jupyterlab/apputils");
const classnames_1 = require("classnames");
class ConnectionEditorModel extends apputils_1.VDomModel {
    constructor(initialConnectionUrl) {
        super();
        this._connectionUrlChanged = new signaling_1.Signal(this);
        this._connect = new signaling_1.Signal(this);
        this._connectionUrl = initialConnectionUrl;
    }
    tryConnect(connectionUrl) {
        this._connect.emit(connectionUrl);
    }
    get connectionUrl() {
        return this._connectionUrl;
    }
    set connectionUrl(newValue) {
        this._connectionUrl = newValue;
        this._connectionUrlChanged.emit(newValue);
    }
    get connect() {
        return this._connect;
    }
    get connectionUrlChanged() {
        return this._connectionUrlChanged;
    }
}
exports.ConnectionEditorModel = ConnectionEditorModel;
class ConnectionEditor extends apputils_1.VDomRenderer {
    static withModel(model) {
        const editor = new ConnectionEditor();
        editor.model = model;
        return editor;
    }
    onActivateRequest() {
        this.node.querySelector('input').focus();
    }
    render() {
        if (!this.model) {
            return null;
        }
        else {
            const connectionUrl = this.model.connectionUrl;
            return (React.createElement("div", { className: "p-Sql-ConnectionInformation-container" },
                React.createElement(ConnectionInformationEdit, { initialConnectionUrl: connectionUrl, onConnectionUrlChanged: newConnectionUrl => (this.model.connectionUrl = newConnectionUrl), onFinishEdit: currentConnectionUrl => this.model.tryConnect(currentConnectionUrl) }),
                React.createElement(ConnectionInformationHelper, null)));
        }
    }
}
exports.ConnectionEditor = ConnectionEditor;
class ConnectionInformationEdit extends React.Component {
    constructor(props) {
        super(props);
        this.inputRef = React.createRef();
        this.state = {
            connectionUrl: props.initialConnectionUrl,
            focused: false
        };
    }
    onKeyDown(event) {
        if (event.key === 'Enter') {
            this.finish();
        }
        else if (event.keyCode === 27) {
            // ESC key
            this.cancel();
        }
    }
    onChange(event) {
        const newConnectionUrl = event.target.value;
        this.props.onConnectionUrlChanged(newConnectionUrl);
        this.setState({ connectionUrl: newConnectionUrl });
    }
    start() {
        this.setState({
            focused: true
        });
    }
    finish() {
        this.props.onFinishEdit(this.state.connectionUrl);
        this.setState({
            focused: false
        });
    }
    cancel() {
        const newConnectionUrl = this.props.initialConnectionUrl;
        this.props.onConnectionUrlChanged(newConnectionUrl);
        this.setState({ connectionUrl: newConnectionUrl });
    }
    onInputFocus() {
        this.start();
    }
    onInputBlur() {
        this.setState({
            focused: false
        });
    }
    componentDidMount() {
        this.inputRef.current.focus();
    }
    render() {
        const { connectionUrl, focused } = this.state;
        const inputWrapperClass = classnames_1.default('p-Sql-ConnectionInformation-input-wrapper', { 'p-mod-focused': focused });
        return (React.createElement("div", { className: "p-Sql-ConnectionInformation-wrapper" },
            React.createElement("div", { className: inputWrapperClass },
                React.createElement("input", { className: "p-Sql-ConnectionInformation-text p-Sql-ConnectionInformation-input", value: connectionUrl, ref: this.inputRef, autoFocus: true, onChange: event => this.onChange(event), onKeyDown: event => this.onKeyDown(event), onBlur: () => this.onInputBlur(), onFocus: () => this.onInputFocus() }))));
    }
}
class ConnectionInformationHelper extends React.Component {
    render() {
        return (React.createElement("details", { className: "jp-RenderedHTMLCommon" },
            React.createElement("summary", null, "Help"),
            React.createElement("p", null,
                "Press ",
                React.createElement("code", null, "Enter"),
                " to connect to the database."),
            React.createElement("p", null,
                "The URL must be a database URL. Follow the",
                ' ',
                React.createElement("a", { href: "https://docs.sqlalchemy.org/en/13/core/engines.html#database-urls", target: "_blank" }, "SQLAlchemy guide"),
                ' ',
                "on URLs. For instance:"),
            React.createElement("ul", null,
                React.createElement("li", null,
                    React.createElement("pre", null, "postgres://localhost:5432/postgres")),
                React.createElement("li", null,
                    React.createElement("pre", null, "postgres://username:password@localhost:5432/postgres")),
                React.createElement("li", null,
                    React.createElement("pre", null, "mysql://localhost/employees")),
                React.createElement("li", null,
                    React.createElement("pre", null, "sqlite://")),
                React.createElement("li", null,
                    React.createElement("pre", null, "sqlite:///myfile.db")))));
    }
}
