"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const widgets_1 = require("@phosphor/widgets");
const disposable_1 = require("@phosphor/disposable");
const apputils_1 = require("@jupyterlab/apputils");
const connectionEditor_1 = require("./connectionEditor");
const page_1 = require("../page");
const services_1 = require("../services");
class ConnectionPage {
    constructor(options) {
        this.pageName = page_1.PageName.Connection;
        const { initialConnectionString } = options;
        this._content = new Content(initialConnectionString);
        this._connectDatabase = services_1.proxyFor(this._content.connectDatabase, this);
        this._connectionUrlChanged = services_1.proxyFor(this._content.connectionUrlChanged, this);
        this._toolbar = new apputils_1.Toolbar();
        this._disposables = disposable_1.DisposableSet.from([this._content, this._toolbar]);
    }
    get content() {
        return this._content;
    }
    get connectDatabase() {
        return this._connectDatabase;
    }
    get connectionUrlChanged() {
        return this._connectionUrlChanged;
    }
    get toolbar() {
        return this._toolbar;
    }
    get isDisposed() {
        return this._disposables.isDisposed;
    }
    dispose() {
        return this._disposables.dispose();
    }
}
exports.ConnectionPage = ConnectionPage;
class Content extends widgets_1.BoxPanel {
    constructor(initialConnectionString) {
        super();
        this.addClass('p-Sql-MainContainer');
        const connectionEditorModel = new connectionEditor_1.ConnectionEditorModel(initialConnectionString);
        this._connectionWidget = connectionEditor_1.ConnectionEditor.withModel(connectionEditorModel);
        this.addWidget(this._connectionWidget);
        widgets_1.BoxPanel.setStretch(this._connectionWidget, 1);
        this._connectDatabase = services_1.proxyFor(connectionEditorModel.connect, this);
        this._connectionUrlChanged = services_1.proxyFor(connectionEditorModel.connectionUrlChanged, this);
    }
    get connectDatabase() {
        return this._connectDatabase;
    }
    get connectionUrlChanged() {
        return this._connectionUrlChanged;
    }
    onActivateRequest() {
        this._connectionWidget.activate();
    }
}
