"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const classnames_1 = require("classnames");
const signaling_1 = require("@phosphor/signaling");
const apputils_1 = require("@jupyterlab/apputils");
class DatabaseSummaryModel extends apputils_1.VDomModel {
    constructor(tables) {
        super();
        this._navigateToTable = new signaling_1.Signal(this);
        this._navigateToCustomQuery = new signaling_1.Signal(this);
        this.tables = tables;
        this.onNavigateToTable = this.onNavigateToTable.bind(this);
        this.onNavigateToCustomQuery = this.onNavigateToCustomQuery.bind(this);
    }
    get navigateToTable() {
        return this._navigateToTable;
    }
    get navigateToCustomQuery() {
        return this._navigateToCustomQuery;
    }
    onNavigateToTable(tableName) {
        this._navigateToTable.emit(tableName);
    }
    onNavigateToCustomQuery() {
        this._navigateToCustomQuery.emit(void 0);
    }
}
exports.DatabaseSummaryModel = DatabaseSummaryModel;
class DatabaseSummaryWidget extends apputils_1.VDomRenderer {
    constructor() {
        super();
        this.addClass('p-Sql-DatabaseSummary-Container');
    }
    static withModel(model) {
        const tableList = new DatabaseSummaryWidget();
        tableList.model = model;
        return tableList;
    }
    render() {
        if (!this.model) {
            return null;
        }
        else {
            const { tables, onNavigateToTable, onNavigateToCustomQuery } = this.model;
            return (React.createElement(TableList, { tableNames: tables, onNavigateToTable: onNavigateToTable, onNavigateToCustomQuery: onNavigateToCustomQuery }));
        }
    }
}
exports.DatabaseSummaryWidget = DatabaseSummaryWidget;
class TableList extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            selectedItem: null
        };
        this.onTableItemClick = this.onTableItemClick.bind(this);
    }
    onTableItemClick(itemNumber) {
        this.setState({ selectedItem: itemNumber });
    }
    render() {
        const { tableNames, onNavigateToTable, onNavigateToCustomQuery } = this.props;
        const { selectedItem } = this.state;
        const tableItems = tableNames.map((tableName, i) => (React.createElement(TableListItem, { tableName: tableName, key: i, onClick: () => this.onTableItemClick(i), onDoubleClick: () => onNavigateToTable(tableName), selected: i === selectedItem })));
        return (React.createElement("div", { className: "p-Sql-TableList-container" },
            React.createElement("ul", { className: "p-Sql-TableList-content" },
                React.createElement(ListHeader, { headerText: "Actions" }),
                React.createElement(CustomQueryItem, { onClick: onNavigateToCustomQuery }),
                React.createElement(ListHeader, { headerText: "Tables" }),
                tableItems)));
    }
}
class TableListItem extends React.Component {
    render() {
        const { tableName, onClick, onDoubleClick, selected } = this.props;
        const classes = classnames_1.default('jp-DirListing-item', {
            'jp-mod-selected': selected
        });
        return (React.createElement("li", { onClick: onClick, onDoubleClick: onDoubleClick, className: classes, title: tableName },
            React.createElement("span", { className: "jp-DirListing-itemIcon jp-MaterialIcon jp-SpreadsheetIcon" }),
            React.createElement("span", { className: "jp-DirListing-itemText" }, tableName)));
    }
}
class CustomQueryItem extends React.Component {
    render() {
        const { onClick } = this.props;
        return (React.createElement("li", { onClick: onClick, className: "jp-DirListing-item", title: "Custom SQL query" },
            React.createElement("span", { className: "jp-DirListing-itemIcon jp-MaterialIcon jp-CodeConsoleIcon" }),
            React.createElement("span", { className: "jp-DirListing-itemText" }, "Custom SQL query")));
    }
}
class ListHeader extends React.Component {
    render() {
        const { headerText } = this.props;
        return React.createElement("li", { className: "p-Sql-TableList-header" }, headerText);
    }
}
