"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const signaling_1 = require("@phosphor/signaling");
const disposable_1 = require("@phosphor/disposable");
const components_1 = require("../components");
const Api = require("../api");
const services_1 = require("../services");
const page_1 = require("../page");
const toolbar_1 = require("./toolbar");
const content_1 = require("./content");
class DatabaseSummaryPage {
    constructor(options) {
        this.pageName = page_1.PageName.DatabaseSummary;
        this._onRefresh = this._onRefresh.bind(this);
        this._content = new Content(options);
        this._toolbar = new toolbar_1.DatabaseSummaryToolbar(options.connectionUrl);
        this._navigateBack = services_1.proxyFor(this._toolbar.backButtonClicked, this);
        this._toolbar.refreshButtonClicked.connect(this._onRefresh);
        this._customQueryClicked = services_1.proxyFor(this._content.customQueryClicked, this);
        this._navigateToTable = services_1.proxyFor(this._content.navigateToTable, this);
        this._disposables = disposable_1.DisposableSet.from([this._content, this._toolbar]);
        this._onRefresh();
    }
    get content() {
        return this._content;
    }
    get toolbar() {
        return this._toolbar;
    }
    get navigateBack() {
        return this._navigateBack;
    }
    get customQueryClicked() {
        return this._customQueryClicked;
    }
    get navigateToTable() {
        return this._navigateToTable;
    }
    get isDisposed() {
        return this._disposables.isDisposed;
    }
    dispose() {
        return this._disposables.dispose();
    }
    _onRefresh() {
        return __awaiter(this, void 0, void 0, function* () {
            this._toolbar.setLoading(true);
            yield this._content.refresh();
            this._toolbar.setLoading(false);
        });
    }
}
exports.DatabaseSummaryPage = DatabaseSummaryPage;
class Content extends components_1.SingletonPanel {
    constructor(options) {
        super();
        this._customQueryClicked = new signaling_1.Signal(this);
        this._navigateToTable = new signaling_1.Signal(this);
        this._connectionUrl = options.connectionUrl;
    }
    get customQueryClicked() {
        return this._customQueryClicked;
    }
    get navigateToTable() {
        return this._navigateToTable;
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield Api.getDatabaseStructure(this._connectionUrl);
            this._setResponse(response);
        });
    }
    dispose() {
        this._disposeWidgets();
        super.dispose();
    }
    _setResponse(response) {
        this._disposeWidgets();
        Api.DatabaseStructureResponse.match(response, tables => {
            const model = new content_1.DatabaseSummaryModel(tables);
            this.widget = content_1.DatabaseSummaryWidget.withModel(model);
            model.navigateToCustomQuery.connect(() => {
                this._customQueryClicked.emit(void 0);
            });
            model.navigateToTable.connect((_, tableName) => {
                this._navigateToTable.emit(tableName);
            });
            this._databaseSummaryModel = model;
        }, ({ message }) => {
            this.widget = new components_1.PreWidget(message);
        });
    }
    _disposeWidgets() {
        if (this._databaseSummaryModel) {
            signaling_1.Signal.disconnectBetween(this._databaseSummaryModel, this);
            this._databaseSummaryModel.dispose();
        }
    }
}
