"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const uuid = require("uuid");
const widgets_1 = require("@phosphor/widgets");
const signaling_1 = require("@phosphor/signaling");
const disposable_1 = require("@phosphor/disposable");
const Api = require("../api");
const page_1 = require("../page");
const services_1 = require("../services");
const response_1 = require("./response");
const editor_1 = require("./editor");
const toolbar_1 = require("./toolbar");
class QueryPage {
    constructor(options) {
        this.pageName = page_1.PageName.CustomQuery;
        this._onExecutionStarted = this._onExecutionStarted.bind(this);
        this._onExecutionFinished = this._onExecutionFinished.bind(this);
        this._content = new Content(options);
        this._toolbar = new toolbar_1.QueryToolbar(options.connectionUrl);
        this._backButtonClicked = services_1.proxyFor(this._toolbar.backButtonClicked, this);
        this._sqlStatementChanged = services_1.proxyFor(this._content.sqlStatementChanged, this);
        this._content.executionStarted.connect(this._onExecutionStarted);
        this._content.executionFinished.connect(this._onExecutionFinished);
        this._disposables = disposable_1.DisposableSet.from([this._content, this._toolbar]);
    }
    get toolbar() {
        return this._toolbar;
    }
    get content() {
        return this._content;
    }
    get backButtonClicked() {
        return this._backButtonClicked;
    }
    get sqlStatementChanged() {
        return this._sqlStatementChanged;
    }
    get isDisposed() {
        return this._disposables.isDisposed;
    }
    dispose() {
        return this._disposables.dispose();
    }
    _onExecutionStarted() {
        this._toolbar.setLoading(true);
    }
    _onExecutionFinished() {
        this._toolbar.setLoading(false);
    }
}
exports.QueryPage = QueryPage;
class Content extends widgets_1.BoxPanel {
    constructor(options) {
        super();
        this._executionStarted = new signaling_1.Signal(this);
        this._executionFinished = new signaling_1.Signal(this);
        this.addClass('p-Sql-MainContainer');
        this.editor = new editor_1.Editor(options.initialSqlStatement, options.editorFactory);
        this.response = new response_1.Response();
        this.editor.execute.connect((_, value) => {
            this.updateGrid(options.connectionUrl, value);
        });
        this._sqlStatementChanged = services_1.proxyFor(this.editor.valueChanged, this);
        this.addWidget(this.editor.widget);
        this.addWidget(this.response.widget);
        widgets_1.BoxPanel.setStretch(this.editor.widget, 1);
        widgets_1.BoxPanel.setStretch(this.response.widget, 3);
    }
    get sqlStatementValue() {
        return this.editor.value;
    }
    get sqlStatementChanged() {
        return this._sqlStatementChanged;
    }
    get executionStarted() {
        return this._executionStarted;
    }
    get executionFinished() {
        return this._executionFinished;
    }
    onActivateRequest(_) {
        this.editor.widget.activate();
    }
    updateGrid(connectionUrl, sql) {
        return __awaiter(this, void 0, void 0, function* () {
            this._executionStarted.emit(void 0);
            const thisRequestId = uuid.v4();
            this._lastRequestId = thisRequestId;
            const data = yield Api.getForQuery(connectionUrl, sql);
            if (this._lastRequestId === thisRequestId) {
                // Only update the response widget if the current
                // query is the last query that was dispatched.
                this.response.setResponse(data);
                this._executionFinished.emit(void 0);
            }
        });
    }
}
